@@ -28,16 +28,16 @@ pub enum FieldError {
 }
 
 #[derive(Debug, Clone)]
-pub enum RegexOrStr<'b> {
+pub enum RegexOrString {
     Regex(Regex),
-    Str(&'b str),
+    String(String),
 }
 
-impl<'b> RegexOrStr<'b> {
-    fn split(&'b self, line: &'b [u8]) -> Box<dyn Iterator<Item = &'b [u8]> + 'b> {
+impl RegexOrString {
+    fn split<'a>(&'a self, line: &'a [u8]) -> Box<dyn Iterator<Item = &'a [u8]> + 'a> {
         match self {
-            RegexOrStr::Regex(r) => Box::new(r.split(line)),
-            RegexOrStr::Str(s) => Box::new(line.split_str(s)),
+            RegexOrString::Regex(r) => Box::new(r.split(line)),
+            RegexOrString::String(s) => Box::new(line.split_str(s)),
         }
     }
 }
@@ -151,7 +151,7 @@ impl FieldRange {
     pub fn from_header_list(
         list: &[Regex],
         header: &[u8],
-        delim: &RegexOrStr,
+        delim: &RegexOrString,
         header_is_regex: bool,
         allow_missing: bool,
     ) -> Result<Vec<FieldRange>, FieldError> {
@@ -195,9 +195,15 @@ impl FieldRange {
         Ok(ranges)
     }
 
+    // TODO: There is a very subtle bug in this sorting / mereging code.
+    // The tests have been updated to reflect it. In addition to sometimes merging overlaps, sometimes not,
+    // this will merge everlaps even when their positions are out of order, i.e. I want to output pos 2, then pos 1,
+    // but this will merge that into a range covering 1-2 and forget the pos ordering.
+
     /// Sort and merge overlaps in a set of [`Vec<FieldRange>`].
     pub fn post_process_ranges(ranges: &mut Vec<FieldRange>) {
         ranges.sort();
+
         // merge overlapping ranges
         let mut shifted = 0;
         for i in 0..ranges.len() {
@@ -208,8 +214,7 @@ impl FieldRange {
 
             while j < ranges.len()
                 && ranges[j].low <= ranges[i].high + 1
-                && (ranges[j].pos == ranges[i].pos
-                    || ranges[j].pos.saturating_sub(1) == ranges[i].pos)
+                && ranges[j].pos.saturating_sub(1) == ranges[i].pos
             {
                 let j_high = ranges.remove(j).high;
                 ranges[i].high = max(ranges[i].high, j_high);
@@ -334,6 +339,9 @@ mod test {
         assert_eq!(vec![FieldRange { low: 0, high: 3, pos: 0}], FieldRange::from_list("-4").unwrap());
         assert_eq!(vec![FieldRange { low: 0, high: 7, pos: 0}], FieldRange::from_list("-4,5-8").unwrap());
         assert_eq!(vec![FieldRange { low: 0, high: 0, pos: 1 }, FieldRange { low: 2, high: 2, pos: 0}, FieldRange { low: 2, high: 2, pos: 2}], FieldRange::from_list("3,1,3").unwrap());
+        // Note the slightly odd pos ordering that happens here. This is an artifact of post_process_ranges, which needs some love
+        assert_eq!(vec![FieldRange { low: 0, high: 1, pos: 0 }, FieldRange { low: 2, high: 2, pos: 1}, FieldRange { low: 3, high: 3, pos: 2}], FieldRange::from_list("1,2,3,4").unwrap());
+        assert_eq!(vec![FieldRange { low: 0, high: 1, pos: 0 }, FieldRange { low: 2, high: 2, pos: 2}, FieldRange { low: 3, high: 3, pos: 1}], FieldRange::from_list("1,2,4,3").unwrap());
     }
 
     #[test]
@@ -349,7 +357,7 @@ mod test {
     fn test_parse_header_fields() {
         let header = b"is_cat-isdog-wascow-was_is_apple-12345-!$%*(_)";
         let delim = Regex::new("-").unwrap();
-        let delim = RegexOrStr::Regex(delim);
+        let delim = RegexOrString::Regex(delim);
         let header_fields = vec![
             Regex::new(r"^is_.*$").unwrap(),
             Regex::new("dog").unwrap(),
@@ -378,7 +386,7 @@ mod test {
     fn test_parse_header_fields_literal() {
         let header = b"is_cat-is-isdog-wascow-was_is_apple-12345-!$%*(_)";
         let delim = Regex::new("-").unwrap();
-        let delim = RegexOrStr::Regex(delim);
+        let delim = RegexOrString::Regex(delim);
         let header_fields = vec![Regex::new(r"is").unwrap()];
         let fields =
             FieldRange::from_header_list(&header_fields, header, &delim, false, false).unwrap();
@@ -396,7 +404,7 @@ mod test {
     fn test_parse_header_fields_literal_header_not_found() {
         let header = b"is_cat-is-isdog-wascow-was_is_apple-12345-!$%*(_)";
         let delim = Regex::new("-").unwrap();
-        let delim = RegexOrStr::Regex(delim);
+        let delim = RegexOrString::Regex(delim);
         let header_fields = vec![
             Regex::new(r"^is_.*$").unwrap(),
             Regex::new("dog").unwrap(),
